<template>
    <div>
        <h2>How Can We Help?</h2>
        <p>You can also fill out the form below and one of us will get back to you.</p>

        <ValidationObserver ref="form">
            <div class="row">
                <div class="col-12">
                    <ValidationProvider name="Name" rules="required" v-slot="{ errors }">
                        <input type="text" placeholder="Name" v-model="form.name" class="txtbox">
                        <span class="red--text" v-if="errors.length > 0"> {{ errors[0] }}</span>
                    </ValidationProvider>
                </div>
                <div class="col-12">
                    <ValidationProvider name="Phone Number" rules="required|digits:10" v-slot="{ errors }">
                        <input type="text" placeholder="Phone Number" v-model="form.phone_no" class="txtbox">
                        <span class="red--text" v-if="errors.length > 0"> {{ errors[0] }}</span>
                    </ValidationProvider>
                </div>
                <div class="col-12">
                    <ValidationProvider name="Email" rules="required|email" v-slot="{ errors }">
                        <input type="text" placeholder="Email" v-model="form.email" class="txtbox">
                        <span class="red--text" v-if="errors.length > 0"> {{ errors[0] }}</span>
                    </ValidationProvider>
                </div>
                <div class="col-12">
                    <ValidationProvider name="How may we serve you" rules="required" v-slot="{ errors }">
                        <textarea class="txtbox" cols="100" v-model="form.message"
                            placeholder="How may we serve you?"></textarea>
                        <span class="red--text f-left" v-if="errors.length > 0"> {{ errors[0] }}</span>
                    </ValidationProvider>
                </div>
                <div class="col-12">

                    <v-btn class="btn" :loading="loading" @click="validateForm">
                        SEND
                    </v-btn>


                </div>
                <div class="col-12" v-if="success">

                    <div class="success_div">
                        <span class="material-icons-outlined">check_circle</span>
                        <div class="thanks_cont">
                            <h3>You are awesome!</h3>
                            <p> We will give you a call ASAP</p>
                        </div>
                    </div>


                </div>
            </div>
        </ValidationObserver>
    </div>
</template>
<script>
import { ValidationObserver } from 'vee-validate';

export default {
    data() {
        return {
            form: {},
            errors: {},
            loading: false,
            success: false,
            domain: this.$store.state.front_end_data.domain,
        };
    },
    components: { ValidationObserver },
    methods: {
        validateForm() {
            this.$refs.form.validate().then((success) => {
                if (success) {
                    this.errors = false;
                    this.loading = true;
                    this.form.domain_id = this.domain.id;
                    enquirySubmit('contact_form_submit');
                    this.$axios.$post('/api/store-contact-enquiry-data', this.form)
                        .then(resp => {
                            this.success = true;
                            this.loading = false;
                            this.form = {};
                            this.$refs.form.reset();
                        });
                }
                else {
                    this.errors = this.$refs.form.errors;
                }
            });
        }
    }
}
</script>
